import allure

from service.app_a.asserts.order.asserts_order_rightsorder import AssertsOrderRightsorder
from service.app_a.apis.order import apis_order_rightsorder
from service.app_a.funs.order.rightsorder.funs_order_rightsorder_receive import FunsOrderRightsorderReceive


class FunsOrderRightsorder(AssertsOrderRightsorder, FunsOrderRightsorderReceive):
    @allure.step(title="权益订单导出接口-Y")
    def order_rightsorder_export(self, rightsType="$None$", userId="$None$", receiveDateEnd="$None$", orderMainId="$None$", payDateBegin="$None$", receiveDateBegin="$None$", mobile="$None$", payDateEnd="$None$", rightsOrderId="$None$", useStatus="$None$", _assert=True,  **kwargs):
        """
            url=/order/rightsOrder/export
                params: mobile :  : 手机号码
                params: rightsOrderId :  : 权益订单ID
                params: orderMainId :  : 主订单ID
                params: useStatus :  : 权益使用状态
                params: rightsType :  : 权益类型
                params: receiveDateBegin :  : 权益领取时间 - 开始
                params: receiveDateEnd :  : 权益领取时间 - 结束
                params: payDateBegin :  : 权益支付时间 - 开始
                params: payDateEnd :  : 权益支付时间 - 结束
                params: headers : 请求头
        """
        rightsType = self.get_list_choice(rightsType, list_or_dict=None, key="rightsType")
        userId = self.get_list_choice(userId, list_or_dict=None, key="userId")
        receiveDateEnd = self.get_list_choice(receiveDateEnd, list_or_dict=None, key="receiveDateEnd")
        orderMainId = self.get_list_choice(orderMainId, list_or_dict=None, key="orderMainId")
        payDateBegin = self.get_list_choice(payDateBegin, list_or_dict=None, key="payDateBegin")
        receiveDateBegin = self.get_list_choice(receiveDateBegin, list_or_dict=None, key="receiveDateBegin")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")
        payDateEnd = self.get_list_choice(payDateEnd, list_or_dict=None, key="payDateEnd")
        rightsOrderId = self.get_list_choice(rightsOrderId, list_or_dict=None, key="rightsOrderId")
        useStatus = self.get_list_choice(useStatus, list_or_dict=None, key="useStatus")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_rightsorder.order_rightsorder_export(**_kwargs)

        self.assert_order_rightsorder_export(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="权益订单 - 新增-Y")
    def order_rightsorder_insert(self, rightsId="$None$", rightsName="$None$", rightsType="$None$", userId="$None$", refundDate="$None$", createTime="$None$", receiveDate="$None$", refundBillNo="$None$", updateId="$None$", payBillNo="$None$", payDate="$None$", mobile="$None$", payAmount="$None$", createBy="$None$", rightsOrderId="$None$", updateTime="$None$", orderMainId="$None$", useStatus="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/order/rightsOrder/insert
                params: rightsOrderId : number : 权益订单ID
                params: rightsId : number : 权益ID
                params: rightsType : integer : 权益类型
                params: rightsName : string : 权益名称
                params: orderMainId : string : 主订单ID
                params: mobile : string : 用户手机号
                params: payAmount : string : 支付金额
                params: useStatus : integer : 权益使用状态
                params: receiveDate : string : 权益领取时间
                params: payDate : string : 权益支付时间
                params: refundDate : string : 权益退款时间
                params: payBillNo : string : 支付流水
                params: refundBillNo : string : 退款流水
                params: createTime : string : 创建时间
                params: createBy : number : 创建人
                params: updateTime : string : 更新时间
                params: updateId : number : 更新人id
                params: headers : 请求头
        """
        rightsId = self.get_value_choice(rightsId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        rightsName = self.get_value_choice(rightsName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        rightsType = self.get_value_choice(rightsType, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        userId = self.get_value_choice(userId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        refundDate = self.get_value_choice(refundDate, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        createTime = self.get_value_choice(createTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        receiveDate = self.get_value_choice(receiveDate, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        refundBillNo = self.get_value_choice(refundBillNo, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        updateId = self.get_value_choice(updateId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        payBillNo = self.get_value_choice(payBillNo, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        payDate = self.get_value_choice(payDate, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        mobile = self.get_value_choice(mobile, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        payAmount = self.get_value_choice(payAmount, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        createBy = self.get_value_choice(createBy, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        rightsOrderId = self.get_value_choice(rightsOrderId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        updateTime = self.get_value_choice(updateTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        orderMainId = self.get_value_choice(orderMainId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        useStatus = self.get_value_choice(useStatus, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_rightsorder.order_rightsorder_insert(**_kwargs)

        self.assert_order_rightsorder_insert(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="权益订单 - 分页查询-Y")
    def order_rightsorder_page(self, rightsType="$None$", userId="$None$", current=1, size=10, receiveDateEnd="$None$", orderMainId="$None$", payDateBegin="$None$", receiveDateBegin="$None$", mobile="$None$", payDateEnd="$None$", rightsOrderId="$None$", useStatus="$None$", _assert=True,  **kwargs):
        """
            url=/order/rightsOrder/page
                params: size :  :
                params: current :  :
                params: mobile :  : 手机号码
                params: rightsOrderId :  : 权益订单ID
                params: orderMainId :  : 主订单ID
                params: useStatus :  : 权益使用状态
                params: rightsType :  : 权益类型
                params: receiveDateBegin :  : 权益领取时间 开始
                params: receiveDateEnd :  : 权益领取时间-结束
                params: payDateBegin :  : 权益支付时间 - 开始
                params: payDateEnd :  : 权益支付时间 - 结束
                params: headers : 请求头
        """
        rightsType = self.get_list_choice(rightsType, list_or_dict=None, key="rightsType")
        userId = self.get_list_choice(userId, list_or_dict=None, key="userId")
        receiveDateEnd = self.get_list_choice(receiveDateEnd, list_or_dict=None, key="receiveDateEnd")
        orderMainId = self.get_list_choice(orderMainId, list_or_dict=None, key="orderMainId")
        payDateBegin = self.get_list_choice(payDateBegin, list_or_dict=None, key="payDateBegin")
        receiveDateBegin = self.get_list_choice(receiveDateBegin, list_or_dict=None, key="receiveDateBegin")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")
        payDateEnd = self.get_list_choice(payDateEnd, list_or_dict=None, key="payDateEnd")
        rightsOrderId = self.get_list_choice(rightsOrderId, list_or_dict=None, key="rightsOrderId")
        useStatus = self.get_list_choice(useStatus, list_or_dict=None, key="useStatus")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_rightsorder.order_rightsorder_page(**_kwargs)

        self.assert_order_rightsorder_page(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="权益-领取权益-Y")
    def order_rightsorder_receive(self, rightsId="$None$", orderId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/order/rightsOrder/receive
                params: orderId : string : 子订单ID
                params: rightsId : number : 权益ID
                params: headers : 请求头
        """
        rightsId = self.get_value_choice(rightsId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        orderId = self.get_value_choice(orderId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_rightsorder.order_rightsorder_receive(**_kwargs)

        self.assert_order_rightsorder_receive(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="权益订单 - 查询-Y")
    def order_rightsorder_getorderlist(self, rightsType="$None$", receiveDate="$None$", rightsNameList="$None$", useStatusList="$None$", mobile="$None$", orderMainId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/order/rightsOrder/getOrderList
                params: orderMainId : number : 主订单ID
                params: rightsType : integer : 权益类型
                params: rightsNameList : array : 权益名称
                type : string : None
                params: useStatusList : array : 权益使用状态
                type : integer : None
                params: mobile : string : 用户手机号
                params: receiveDate : string : 权益领取时间
                params: headers : 请求头
        """
        rightsType = self.get_value_choice(rightsType, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        receiveDate = self.get_value_choice(receiveDate, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        rightsNameList = self.get_value_choice(rightsNameList, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        useStatusList = self.get_value_choice(useStatusList, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        mobile = self.get_value_choice(mobile, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        orderMainId = self.get_value_choice(orderMainId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_rightsorder.order_rightsorder_getorderlist(**_kwargs)

        self.assert_order_rightsorder_getorderlist(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="更新充电桩订单状态-Y")
    def order_rightsorder_statusupdate(self, soNo="$None$", workStatus="$None$", _assert=True,  **kwargs):
        """
            url=/order/rightsOrder/statusUpdate
                params: soNo :  : 第三方订单
                params: workStatus :  : 权益使用状态
                params: headers : 请求头
        """
        soNo = self.get_list_choice(soNo, list_or_dict=None, key="soNo")
        workStatus = self.get_list_choice(workStatus, list_or_dict=None, key="workStatus")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_rightsorder.order_rightsorder_statusupdate(**_kwargs)

        self.assert_order_rightsorder_statusupdate(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.asserts.asserts_area import AssertsArea
from service.app_a.apis import apis_area


class FunsArea(AssertsArea):
    @allure.step(title="限行城市-D")
    def area_getcitylist(self, _assert=True,  **kwargs):
        """
            url=/area/getCityList
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_area.area_getcitylist(**_kwargs)

        self.assert_area_getcitylist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/radarpoints/userPoints/pointsInfo/pageList")
def radarpoints_userpoints_pointsinfo_pagelist(userId=None, current=None, size=None, name=None, changeTimeBegin=None, businessSceneType=None, changeTimeEnd=None, headers=None, **kwargs):
    """
    用户中心-积分明细-分页查询
    up_time=1677054547

    params: userId :  : 用户ID
    params: size :  : 每页大小
    params: current :  : 当前页
    params: businessSceneType :  : 10001 转介裂变
10002 营销活动
10003 社区活跃
10004 线下活动
10005 用车行为
10006 评价
10007 内容奖励
10008 后台管理手动操作
20000 其他
    params: name :  : 名称
    params: changeTimeBegin :  : 变动开始时间
    params: changeTimeEnd :  : 变动结束时间
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : number : 每页大小
              current : number : 当前页
              total : number : 总页数
    """
    _method = "GET"
    _url = "/radarpoints/userPoints/pointsInfo/pageList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
        "size": size,  # 每页大小
        "current": current,  # 当前页
        "businessSceneType": businessSceneType,  # 10001 转介裂变 10002 营销活动 10003 社区活跃 10004 线下活动 10005 用车行为 10006 评价 10007 内容奖励 10008 后台管理手动操作 20000 其他
        "name": name,  # 名称
        "changeTimeBegin": changeTimeBegin,  # 变动开始时间
        "changeTimeEnd": changeTimeEnd,  # 变动结束时间
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/radarpoints/pointsTask/pageList")
def radarpoints_pointstask_pagelist(size=None, dateLast=None, getPointsQtySort=None, pointsConfigName=None, pointsTaskDateSort=None, mobile=None, pointsConfigCode=None, current=None, dateBegin=None, headers=None, **kwargs):
    """
    积分任务 - 分页查询
    up_time=1679971837

    params: dateBegin :  : 开始日期
    params: dateLast :  : 结束日期
    params: pointsConfigCode :  : 任务编码
    params: pointsConfigName :  : 任务名称
    params: mobile :  : 用户手机号
    params: pointsTaskDateSort :  : 日期排序字段，"ASC"升序，"DESC"降序
    params: getPointsQtySort :  : 积分值排序字段，"ASC"升序，"DESC"降序
    params: current :  : 页码
    params: size :  : 每页大小
    params: headers : 请求头
    ====================返回======================
    params: code : number : 200：成功
    params: msg : string : 信息
    params: data : object : 数据
              records : array : 分页数据
              total : string : 总条数
              current : string : 页码
              size : string : 每页大小
              pages : number : 总页数
    """
    _method = "GET"
    _url = "/radarpoints/pointsTask/pageList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "dateBegin": dateBegin,  # 开始日期
        "dateLast": dateLast,  # 结束日期
        "pointsConfigCode": pointsConfigCode,  # 任务编码
        "pointsConfigName": pointsConfigName,  # 任务名称
        "mobile": mobile,  # 用户手机号
        "pointsTaskDateSort": pointsTaskDateSort,  # 日期排序字段，"ASC"升序，"DESC"降序
        "getPointsQtySort": getPointsQtySort,  # 积分值排序字段，"ASC"升序，"DESC"降序
        "current": current,  # 页码
        "size": size,  # 每页大小
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/radarpoints/pointsTask/export")
def radarpoints_pointstask_export(dateLast=None, getPointsQtySort=None, pointsConfigName=None, pointsTaskDateSort=None, mobile=None, pointsConfigCode=None, dateBegin=None, headers=None, **kwargs):
    """
    积分任务 - 导出excel
    up_time=1679971864

    params: dateBegin :  : 开始日期
    params: dateLast :  : 结束日期
    params: pointsConfigCode :  : 任务编码
    params: pointsConfigName :  : 任务名称
    params: mobile :  : 用户手机号
    params: pointsTaskDateSort :  : 日期排序字段，"ASC"升序，"DESC"降序
    params: getPointsQtySort :  : 积分值排序字段，"ASC"升序，"DESC"降序
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/radarpoints/pointsTask/export"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "dateBegin": dateBegin,  # 开始日期
        "dateLast": dateLast,  # 结束日期
        "pointsConfigCode": pointsConfigCode,  # 任务编码
        "pointsConfigName": pointsConfigName,  # 任务名称
        "mobile": mobile,  # 用户手机号
        "pointsTaskDateSort": pointsTaskDateSort,  # 日期排序字段，"ASC"升序，"DESC"降序
        "getPointsQtySort": getPointsQtySort,  # 积分值排序字段，"ASC"升序，"DESC"降序
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a.asserts.common.asserts_common_common import AssertsCommonCommon
from service.app_a.apis.common import apis_common_common


class FunsCommonCommon(AssertsCommonCommon):
    @allure.step(title="文章-获取发布渠道-Y")
    def common_common_getchannel(self, _assert=True,  **kwargs):
        """
            url=/common/common/getChannel
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_common.common_common_getchannel(**_kwargs)

        self.assert_common_common_getchannel(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/radarpoints/PointsConfig/page")
def radarpoints_pointsconfig_page(code=None, pointsBegin=None, size=None, name=None, pointsExpiration=None, Current=None, pointsEnd=None, status=None, businessSceneType=None, headers=None, **kwargs):
    """
    积分配置 - 分页查询
    up_time=1680142594

    params: code :  : 积分项Code
    params: name :  : 积分项名称
    params: businessSceneType :  : 发放场景类型
    params: pointsBegin :  : 积分值 - 开始区间
    params: pointsEnd :  : 积分值 - 结束区间
    params: pointsExpiration :  : 积分有效期
    params: status :  : 生效状态（0未生效，1已生效）
    params: Current :  : 当前页
    params: size :  : 每页大小
    params: headers : 请求头
    ====================返回======================
    params: code : integer : 
    params: msg : string : 
    params: data : object : 
              code : string : 积分项编码
              name : string : 积分项名称
              businessSceneType : string : 发放场景类型
              points : integer : 积分值
              toast : string : toast内容
              PointsExpiration : string : 积分有效期
              status : integer : 状态值
              statusName : string : 状态名称
              remark : string : 备注
              rulesPointsDayMax : integer : 积分获取-分数上限
              userPointsDayMax : integer : 单用户单日上限
              pointsOperator : string : bpm单号
              bpmId : string : 积分操作者
    """
    _method = "GET"
    _url = "/radarpoints/PointsConfig/page"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "code": code,  # 积分项Code
        "name": name,  # 积分项名称
        "businessSceneType": businessSceneType,  # 发放场景类型
        "pointsBegin": pointsBegin,  # 积分值 - 开始区间
        "pointsEnd": pointsEnd,  # 积分值 - 结束区间
        "pointsExpiration": pointsExpiration,  # 积分有效期
        "status": status,  # 生效状态（0未生效，1已生效）
        "Current": Current,  # 当前页
        "size": size,  # 每页大小
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/radarpoints/PointsConfig/insert")
def radarpoints_pointsconfig_insert(remark=None, name=None, points=None, rulesPointsDayMax=None, pointsExpiration=None, bpmId=None, userPointsDayMax=None, toast=None, businessSceneType=None, headers=None, **kwargs):
    """
    积分配置 -新增积分配置
    up_time=1680142659

    params: pointsExpiration : string : 积分有效期
    params: remark : string : 备注
    params: points : integer : 积分值
    params: toast : string : toast内容
    params: name : string : 积分项名称
    params: businessSceneType : integer : 发放场景类型
    params: bpmId : integer : bpm单号
    params: userPointsDayMax : integer : 单用户单日上限
    params: rulesPointsDayMax : integer : 单日上限
    params: headers : 请求头
    ====================返回======================
    params: code : integer : 
    params: msg : string : 
    params: data : string : 
    """
    _method = "POST"
    _url = "/radarpoints/PointsConfig/insert"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "pointsExpiration": pointsExpiration,  # 积分有效期
        "remark": remark,  # 备注
        "points": points,  # 积分值
        "toast": toast,  # toast内容
        "name": name,  # 积分项名称
        "businessSceneType": businessSceneType,  # 发放场景类型
        "bpmId": bpmId,  # bpm单号
        "userPointsDayMax": userPointsDayMax,  # 单用户单日上限
        "rulesPointsDayMax": rulesPointsDayMax,  # 单日上限
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/radarpoints/PointsConfig/update")
def radarpoints_pointsconfig_update(remark=None, code=None, name=None, points=None, rulesPointsDayMax=None, pointsExpiration=None, userPointsDayMax=None, bpmId=None, id=None, toast=None, businessSceneType=None, headers=None, **kwargs):
    """
    积分配置 -修改积分配置
    up_time=1680142897

    params: pointsExpiration : string : 积分有效期
    params: remark : string : 备注
    params: points : integer : 积分值
    params: toast : string : toast内容
    params: name : string : 积分项名称
    params: businessSceneType : integer : 发放场景类型
    params: id : integer : 积分项id
    params: code : string : 积分项code
    params: rulesPointsDayMax : integer : 单日上限
    params: userPointsDayMax : integer : 单用户单日上限
    params: bpmId : integer : bpm单号
    params: headers : 请求头
    ====================返回======================
    params: code : integer : 
    params: msg : string : 
    params: data : string : 
    """
    _method = "POST"
    _url = "/radarpoints/PointsConfig/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "pointsExpiration": pointsExpiration,  # 积分有效期
        "remark": remark,  # 备注
        "points": points,  # 积分值
        "toast": toast,  # toast内容
        "name": name,  # 积分项名称
        "businessSceneType": businessSceneType,  # 发放场景类型
        "id": id,  # 积分项id
        "code": code,  # 积分项code
        "rulesPointsDayMax": rulesPointsDayMax,  # 单日上限
        "userPointsDayMax": userPointsDayMax,  # 单用户单日上限
        "bpmId": bpmId,  # bpm单号
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/radarpoints/PointsConfig/updateStatusById")
def radarpoints_pointsconfig_updatestatusbyid(id=None, status=None, headers=None, **kwargs):
    """
    积分配置 -生效状态变更
    up_time=1676455564

    params: id :  : 积分id
    params: status :  : 生效状态（0未生效，1已生效）
    params: headers : 请求头
    ====================返回======================
    params: code : integer : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "GET"
    _url = "/radarpoints/PointsConfig/updateStatusById"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "id": id,  # 积分id
        "status": status,  # 生效状态（0未生效，1已生效）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/testDrive/subscribe")
def testdrive_subscribe(appointmentTime=None, shopName=None, phoneNumber=None, channel=None, leadSourceCode=None, model=None, shopId=None, activityCode=None, customerName=None, modelId=None, leadSanSourceCode=None, headers=None, **kwargs):
    """
    预约试驾
    up_time=1689560965

    params: model : text : 试驾车型名称
    params: shopName : text : 门店名称
    params: customerName : text : 客户姓名、昵称
    params: phoneNumber : text : 预留手机号
    params: channel : text : 1:移动应用 2:小程序 3:官方网站
    params: modelId : text : 预约车型id
    params: shopId : text : 预约门店id
    params: appointmentTime : text : 预约时间
    params: activityCode : string : 活动代码
    params: leadSourceCode : string : 线索来源小类
    params: leadSanSourceCode : string : 线索来源三级小类
    params: headers : 请求头
    ====================返回======================
    params: code : string : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/testDrive/subscribe"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "model": model,  # 试驾车型名称
        "shopName": shopName,  # 门店名称
        "customerName": customerName,  # 客户姓名、昵称
        "phoneNumber": phoneNumber,  # 预留手机号
        "channel": channel,  # 1:移动应用 2:小程序 3:官方网站
        "modelId": modelId,  # 预约车型id
        "shopId": shopId,  # 预约门店id
        "appointmentTime": appointmentTime,  # 预约时间
        "activityCode": activityCode,  # 活动代码
        "leadSourceCode": leadSourceCode,  # 线索来源小类
        "leadSanSourceCode": leadSanSourceCode,  # 线索来源三级小类
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a.asserts.common.asserts_common_user import AssertsCommonUser
from service.app_a.apis.common import apis_common_user


class FunsCommonUser(AssertsCommonUser):
    @allure.step(title="获取管理后台用户的小号（马甲）-Y")
    def common_user_getuservestlist(self, _assert=True,  **kwargs):
        """
            url=/common/user/getUserVestList
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_user.common_user_getuservestlist(**_kwargs)

        self.assert_common_user_getuservestlist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


